@@ -13,6 +13,7 @@
 """Placeholder docstring"""
 from __future__ import absolute_import
 
+import logging
 from typing import Union, Optional
 
 from sagemaker import image_uris
@@ -26,6 +27,9 @@ from sagemaker.session import Session
 from sagemaker.utils import pop_out_unused_kwarg
 from sagemaker.vpc_utils import VPC_CONFIG_DEFAULT
 from sagemaker.workflow.entities import PipelineVariable
+from sagemaker.workflow import is_pipeline_variable
+
+logger = logging.getLogger(__name__)
 
 
 class LDA(AmazonAlgorithmEstimatorBase):
@@ -37,24 +41,24 @@ class LDA(AmazonAlgorithmEstimatorBase):
     word, and the categories are the topics.
     """
 
-    repo_name = "lda"
-    repo_version = 1
+    repo_name: str = "lda"
+    repo_version: str = "1"
 
-    num_topics = hp("num_topics", gt(0), "An integer greater than zero", int)
-    alpha0 = hp("alpha0", gt(0), "A positive float", float)
-    max_restarts = hp("max_restarts", gt(0), "An integer greater than zero", int)
-    max_iterations = hp("max_iterations", gt(0), "An integer greater than zero", int)
-    tol = hp("tol", gt(0), "A positive float", float)
+    num_topics: hp = hp("num_topics", gt(0), "An integer greater than zero", int)
+    alpha0: hp = hp("alpha0", gt(0), "A positive float", float)
+    max_restarts: hp = hp("max_restarts", gt(0), "An integer greater than zero", int)
+    max_iterations: hp = hp("max_iterations", gt(0), "An integer greater than zero", int)
+    tol: hp = hp("tol", gt(0), "A positive float", float)
 
     def __init__(
         self,
-        role,
-        instance_type=None,
-        num_topics=None,
-        alpha0=None,
-        max_restarts=None,
-        max_iterations=None,
-        tol=None,
+        role: str,
+        instance_type: Optional[Union[str, PipelineVariable]] = None,
+        num_topics: Optional[int] = None,
+        alpha0: Optional[float] = None,
+        max_restarts: Optional[int] = None,
+        max_iterations: Optional[int] = None,
+        tol: Optional[float] = None,
         **kwargs
     ):
         """Latent Dirichlet Allocation (LDA) is :class:`Estimator` used for unsupervised learning.
@@ -102,7 +106,7 @@ class LDA(AmazonAlgorithmEstimatorBase):
                 endpoints use this role to access training data and model
                 artifacts. After the endpoint is created, the inference code
                 might use the IAM role, if accessing AWS resource.
-            instance_type (str): Type of EC2 instance to use for training,
+            instance_type (str or PipelineVariable): Type of EC2 instance to use for training,
                 for example, 'ml.c4.xlarge'.
             num_topics (int): The number of topics for LDA to find within the
                 data.
@@ -124,11 +128,10 @@ class LDA(AmazonAlgorithmEstimatorBase):
             :class:`~sagemaker.estimator.EstimatorBase`.
         """
         # this algorithm only supports single instance training
-        if kwargs.pop("instance_count", 1) != 1:
-            print(
-                "LDA only supports single instance training. Defaulting to 1 {}.".format(
-                    instance_type
-                )
+        instance_count = kwargs.pop("instance_count", 1)
+        if is_pipeline_variable(instance_count) or instance_count != 1:
+            logger.warning(
+                "LDA only supports single instance training. Defaulting to 1 %s.", instance_type
             )
 
         super(LDA, self).__init__(role, 1, instance_type, **kwargs)
@@ -234,7 +237,7 @@ class LDAModel(Model):
         """Initialization for LDAModel class.
 
         Args:
-            model_data (str): The S3 location of a SageMaker model data
+            model_data (str or PipelineVariable): The S3 location of a SageMaker model data
                 ``.tar.gz`` file.
             role (str): An AWS IAM role (either name or full ARN). The Amazon
                 SageMaker training jobs and APIs that create Amazon SageMaker
